@@ -90,8 +90,14 @@ class TestCollect(testtools.TestCase):
         self._call_main(occ_args)
         proc_args = calls[0]
         self.assertEqual(expected_cmd, proc_args['args'])
+        list_path = os.path.join(cache_dir.path, 'os_config_files.json')
+        with open(list_path) as list_file:
+            config_list = json.loads(list_file.read())
+        self.assertThat(config_list, matchers.IsInstance(list))
+        env_config_list = proc_args['env']['OS_CONFIG_FILES'].split(':')
+        self.assertEquals(env_config_list, config_list)
         keys_found = set()
-        for path in proc_args['env']['OS_CONFIG_FILES'].split(':'):
+        for path in env_config_list:
             self.assertTrue(os.path.exists(path))
             with open(path) as cfg_file:
                 contents = json.loads(cfg_file.read())
@@ -156,6 +162,21 @@ class TestCollect(testtools.TestCase):
         self.assertIn('ec2', out_struct)
         self.assertIn('cfn', out_struct)
 
+    def test_main_print_cachedir(self):
+        fake_cachedir = self.useFixture(fixtures.TempDir())
+        fake_args = [
+            'os-collect-config',
+            '--cachedir', fake_cachedir.path,
+            '--config-file', '/dev/null',
+            '--print-cachedir',
+        ]
+        output = self.useFixture(fixtures.StringStream('stdout'))
+        self.useFixture(
+            fixtures.MonkeyPatch('sys.stdout', output.stream))
+        self._call_main(fake_args)
+        cache_dir = output.getDetails()['stdout'].as_text().strip()
+        self.assertEquals(fake_cachedir.path, cache_dir)
+
     def test_main_invalid_collector(self):
         fake_args = ['os-collect-config', 'invalid']
         self.assertRaises(exc.InvalidArguments, self._call_main, fake_args)
@@ -289,3 +310,37 @@ class TestHup(testtools.TestCase):
     def test_reexec_self(self):
         collect.reexec_self()
         self.assertNotIn('Signal received', self.log.output)
+
+
+class TestFileHash(testtools.TestCase):
+    def setUp(self):
+        super(TestFileHash, self).setUp()
+
+        # Deletes tempfiles during teardown
+        self.useFixture(fixtures.NestedTempfile())
+
+        self.file_1 = tempfile.mkstemp()[1]
+        with open(self.file_1, "w") as fp:
+            fp.write("test string")
+
+        self.file_2 = tempfile.mkstemp()[1]
+        with open(self.file_2, "w") as fp:
+            fp.write("test string2")
+
+    def test_getfilehash_nofile(self):
+        h = collect.getfilehash([])
+        self.assertEquals(h, "d41d8cd98f00b204e9800998ecf8427e")
+
+    def test_getfilehash_onefile(self):
+        h = collect.getfilehash([self.file_1])
+        self.assertEquals(h, "6f8db599de986fab7a21625b7916589c")
+
+    def test_getfilehash_twofiles(self):
+        h = collect.getfilehash([self.file_1, self.file_2])
+        self.assertEquals(h, "a8e1b2b743037b1ec17b5d4b49369872")
+
+    def test_getfilehash_filenotfound(self):
+        self.assertEquals(
+            collect.getfilehash([self.file_1, self.file_2]),
+            collect.getfilehash([self.file_1, "/i/dont/exist", self.file_2])
+        )
